ArchiveOptions class

Options for the archive operation.

Constructors

ArchiveOptions({required List<FileSystemEntity> entities, required String basePath, required File outputFile, bool useGzip = true, StringBuffer? logBuffer, void onSuccess()?, void onError(Object, StackTrace?)?, StreamController<TarEntry>? controller, bool autoFillEntities = true})

Properties

autoFillEntities bool
final
basePath String
final
controller StreamController<TarEntry>?
final
entities List<FileSystemEntity>
final
hashCode int
The hash code for this object.
no setterinherited
logBuffer StringBuffer?
final
onError → void Function(Object, StackTrace?)?
final
onSuccess → void Function()?
final
outputFile File
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useGzip bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited