TarHelper class
tar archive | unarchive helper
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
addDirectoryToTarEntry(
Directory directory, String basePath, StreamController< TarEntry> controller, StringBuffer? logBuffer, {bool recursive = true}) → void - Adds all files from a directory to the tar archive controller.
-
addFileToTarEntry(
File file, String basePath, StreamController< TarEntry> controller, StringBuffer? logBuffer) → void - Adds a single file to the tar archive controller.
-
archive(
ArchiveOptions options) → void - Archives entities into a tar file with trace logging.
-
unArchive(
UnArchiveOptions options) → void -
Unarchives
filetotargetDir. Symmetric to archive method.