UnArchiveOptions class
Options for the unarchive operation.
Constructors
- UnArchiveOptions({required File file, required Directory targetDir, StringBuffer? logBuffer, void onSuccess()?, void onError(Object, StackTrace?)?, void onFileExtracted(File extractedFile)?})
Properties
- file → File
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- logBuffer → StringBuffer?
-
final
- onError → void Function(Object, StackTrace?)?
-
final
- onFileExtracted → void Function(File extractedFile)?
-
final
- onSuccess → void Function()?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetDir → Directory
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited